/*
 * Copyright 2015 Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.net.meter;

import com.google.common.base.Objects;
import org.onosproject.net.DeviceId;

/**
 * A meter key represents a meter uniquely.
 */
public final class MeterKey {

    private final DeviceId deviceId;
    private final MeterId id;

    private MeterKey(DeviceId deviceId, MeterId id) {
        this.deviceId = deviceId;
        this.id = id;
    }

    public DeviceId deviceId() {
        return deviceId;
    }

    public MeterId meterId() {
        return id;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        MeterKey meterKey = (MeterKey) o;
        return Objects.equal(deviceId, meterKey.deviceId) &&
                Objects.equal(id, meterKey.id);
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(deviceId, id);
    }

    public static MeterKey key(DeviceId deviceId, MeterId id) {
        return new MeterKey(deviceId, id);
    }
}
